summaryrefslogtreecommitdiff
path: root/test/unit/node/symbol_table_black.cpp
diff options
context:
space:
mode:
authorAina Niemetz <aina.niemetz@gmail.com>2021-03-31 15:23:17 -0700
committerGitHub <noreply@github.com>2021-03-31 22:23:17 +0000
commita1466978fbc328507406d4a121dab4d1a1047e1d (patch)
tree12b40f161bb4d7a6ee40c20c78a15d6cda3c1995 /test/unit/node/symbol_table_black.cpp
parentf9a9af855fb65804ff0b36e764ccd9d0fa9f87f8 (diff)
Rename namespace CVC4 to CVC5. (#6249)
Diffstat (limited to 'test/unit/node/symbol_table_black.cpp')
-rw-r--r--test/unit/node/symbol_table_black.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/unit/node/symbol_table_black.cpp b/test/unit/node/symbol_table_black.cpp
index c1865eaa9..27911c34b 100644
--- a/test/unit/node/symbol_table_black.cpp
+++ b/test/unit/node/symbol_table_black.cpp
@@ -9,9 +9,9 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief Black box testing of CVC4::SymbolTable
**
** Black box testing of CVC4::SymbolTable.
**/
#include <sstream>
@@ -24,7 +24,7 @@
#include "expr/symbol_table.h"
#include "test_api.h"
-namespace CVC4 {
+namespace CVC5 {
using namespace kind;
using namespace context;
@@ -146,4 +146,4 @@ TEST_F(TestNodeBlackSymbolTable, bad_pop)
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,9 +9,9 @@
** directory for licensing information.\endverbatim
**
- ** \brief Black box testing of CVC4::SymbolTable
+ ** \brief Black box testing of CVC5::SymbolTable
**
@@ -9,9 +9,9 @@
**
- ** Black box testing of CVC4::SymbolTable.
+ ** Black box testing of CVC5::SymbolTable.
**/
#include <sstream>